/* --COPYRIGHT--,BSD
// BSD-3-Clause
//
// Copyright (c) 2018, Texas Instruments Incorporated
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
//
// * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// * Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// * Neither the name of Texas Instruments Incorporated nor the names of
// its contributors may be used to endorse or promote products derived
// from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
// OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
// EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
//
//! \file   main.c
//!
//! \brief  This demonstration uses single finger gestures, such as tap,
//!         double-tap, tap-n-hold, swipe and slide on the CAPT-BSWP touch
//!         panel to control a Microsoft Windows media player application.
//!
//!         This application uses the MSP-EXP430F5529LP LaunchPad kit
//!         tool as a USB HID keyboard device.
//!
//!         Refer to the readme.txt file for additional project details.
//!
//
//  Group:          MSP
//  Target Devices: MSP430FR2633
//
//  (C) Copyright 2018, Texas Instruments, Inc.
//#############################################################################
// TI Release: 1.00.00.00
// Release Date: Dec 04, 2018
//#############################################################################

//*****************************************************************************
// Includes
//*****************************************************************************
#include <media_player.h>               // Gesture handlers
#include <msp430.h>                     // Generic MSP430 Device Include
#include "driverlib.h"                  // MSPWare Driver Library
#include "captivate.h"                  // CapTIvate Touch Software Library
#include "CAPT_App.h"                   // CapTIvate Application Code
#include "CAPT_BSP.h"                   // CapTIvate EVM Board Support Package


//*****************************************************************************
// Global Variables
//*****************************************************************************

//*****************************************************************************
// Local Variables
//*****************************************************************************

//*****************************************************************************
// Function Prototypes (forward declarations)
//*****************************************************************************

//*****************************************************************************
// Function Implementations
//*****************************************************************************

void main(void)
{

    WDTCTL = WDTPW | WDTHOLD;

	// Initialize the MCU
	// BSP_configureMCU() sets up the device IO and clocking
	// The global interrupt enable is set to allow peripherals
	// to wake the MCU.
	BSP_configureMCU();

	__bis_SR_register(GIE);

	Demo_Init();

	// Turn both LEDs to show POR activity.
	LED1_ON, LED2_ON;

	// Start the CapTIvate application
	CAPT_appStart();

	LED1_OFF, LED2_OFF;

	// Background Loop
	while(1)
	{

		// Run the captivate application handler.
		CAPT_appHandler();

		CAPT_appSleep();
		
	}
}
