/* --COPYRIGHT--,BSD
// BSD-3-Clause
//
// Copyright (c) 2018, Texas Instruments Incorporated
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
//
// * Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
//
// * Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
//
// * Neither the name of Texas Instruments Incorporated nor the names of
// its contributors may be used to endorse or promote products derived
// from this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
// THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
// PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
// OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
// WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
// EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 1.0.00.00
// Release Date: Dec 4, 2018
//#############################################################################
#ifndef __KEYBOARD__
#define __KEYBOARD__


//*****************************************************************************
// Defines
//*****************************************************************************
#define HIBYTE(x)               (uint8_t)(x && 0xFF00) >> 8
#define LOBYTE(x)               (uint8_t)(x && 0x00FF)

//*****************************************************************************
// Global Variables
//*****************************************************************************
//	Low level key report: up to 6 keys and shift, ctrl etc at once
typedef struct
{
	uint8_t modifiers;
	uint8_t reserved;
	uint8_t keys[6];
} KeyReport;

typedef union {
	uint8_t keyArray[8];
	KeyReport keyReport;
}KeyUnion;

//*****************************************************************************
// Function Prototypes
//*****************************************************************************


//*****************************************************************************
//
// Keyboard_start() performs the following functions:
//  (1) It initializes the HID key report
//  (2) Sets up the I2C communications as MASTER
//
// \param none
// \return none
//
//*****************************************************************************
void Keyboard_start(void);


//*****************************************************************************
//
// Keyboard_getIRQStatus() performs the following functions:
// Returns the status of the keyboard IRQ which is used by the I2C
// slave (MSP430FR2633) to signal it has data ready to read.
//
// \param none
// \return boolean
//
//*****************************************************************************
bool Keyboard_getIRQStatus(void);


//*****************************************************************************
//
// Keyboard_readKey() performs the following functions:
// Reads the current previous key value from the MSP430FR2633 slave.
//
// \param pointers to the current key value and previous key value
// \return none
//
//*****************************************************************************
void Keyboard_read(uint16_t *currentStatus, uint16_t *previousStatus);


//*****************************************************************************
//
// Keyboard_press() performs the following functions:
// Emulates a key press by sending key current and previous values.
//
// \param key value
// \return none
//
//*****************************************************************************
bool Keyboard_press(uint16_t key);


//*****************************************************************************
//
// Keyboard_release() performs the following functions:
// Emulates a key release by sending key current and previous values.
//
// \param key value
// \return none
//
//*****************************************************************************
bool Keyboard_release(uint16_t key);


//*****************************************************************************
//
// Keyboard_sendReport() performs the following functions:
// Sends USB HID keyboard report to HOST.
//
// \param none
// \return none
//
//*****************************************************************************
void Keyboard_sendReport(void);


//*****************************************************************************
//
// Keyboard_updateHIDReport() performs several functions:
//  (1) Updates the HID keypoard report to reflect current and previous keys
//
// \param none
// \return none
//
//*****************************************************************************
void Demo_updateHIDReport(uint16_t ui16CurrentKey, uint16_t ui16PreviousKey);

#endif /* if defined(__KEYBOARD__) */

